@@ -107,6 +107,8 @@ def initialize(backends=("libOpenCL.so", "OpenCL.dll")):
     typedef uint32_t cl_platform_info;
     typedef uint32_t cl_device_info;
     typedef uint32_t cl_program_build_info;
+    typedef cl_uint  cl_program_info;
+    typedef cl_uint  cl_kernel_info;
     typedef uint32_t cl_kernel_work_group_info;
     typedef uint64_t cl_command_queue_properties;
     typedef uint64_t cl_mem_flags;
@@ -158,6 +160,15 @@ def initialize(backends=("libOpenCL.so", "OpenCL.dll")):
                                          const char **strings,
                                          const size_t *lengths,
                                          cl_int *errcode_ret);
+
+    cl_program clCreateProgramWithBinary(cl_context context,
+                                         cl_uint num_devices,
+                                         const cl_device_id *device_list,
+                                         const size_t *lengths,
+                                         const unsigned char **binaries,
+                                         cl_int *binary_status,
+                                         cl_int *errcode_ret);
+
     cl_int clReleaseProgram(cl_program program);
     cl_int clBuildProgram(cl_program program,
                           cl_uint num_devices,
@@ -172,10 +183,22 @@ def initialize(backends=("libOpenCL.so", "OpenCL.dll")):
                                  void *param_value,
                                  size_t *param_value_size_ret);
 
+    cl_int clGetProgramInfo(cl_program program,
+                            cl_program_info param_name,
+                            size_t param_value_size,
+                            void *param_value,
+                            size_t *param_value_size_ret);
+
     cl_kernel clCreateKernel(cl_program program,
                              const char *kernel_name,
                              cl_int *errcode_ret);
     cl_int clReleaseKernel(cl_kernel kernel);
+    cl_int clGetKernelInfo(cl_kernel kernel,
+                           cl_kernel_info param_name,
+                           size_t param_value_size,
+                           void *param_value,
+                           size_t *param_value_size_ret);
+
     cl_int clGetKernelWorkGroupInfo(cl_kernel kernel,
                                     cl_device_id device,
                                     cl_kernel_work_group_info param_name,
